package PiTube::Controller::Stream;
use Mojo::Base 'Mojolicious::Controller';

use constant CONTENT_TYPE => {
    m3u8 => 'application/vnd.apple.mpegurl',
    ts   => 'video/mp2t',
};

sub list {
    my $c = shift;

    my $cond = {
        is_active => 't'
    };

    $cond->{is_public} = 't' if ! $c->is_user_authenticated;

    my $streams = $c->schema->resultset('Stream_view')->search(
        $cond,
        { order_by => 'name' }
    );

    my @streams = ();

    STREAM:
    while ( my $stream = $streams->next()) {

        my $rights = $c->session->{user}{acl}{ $stream->key };

        if ( ! $stream->is_public ) {
            next STREAM if ! $rights;
        }

        my %stream = (
            $stream->get_columns(),
            is_live       => $stream->is_live,
            is_writeable  => $stream->is_writeable( $rights ),
            is_recordable => $stream->is_recordable( $c->session->{user}{username} ),
        );

        delete $stream{publish_user_name} if ! $stream->is_live;

        push @streams, \%stream;
    }

    $c->render( json => \@streams );
}


sub player {
    my $c = shift;

    # vzdy aktualizovat
    $c->session->{user}{acl} = $c->schema->resultset('ACL')->user_acl(
        $c->session->{user}
    );

    # stream
    my $stream = $c->schema->resultset('Stream_view')->find({
        key => $c->stash->{key}
    });

    if ( ! $stream ) {
        $c->render('stream/404');
        return;
    }

    $c->stash->{stream} = {
        $stream->get_columns,
        is_live => $stream->is_live,
    };

    if ( ! ( $c->session->{user}{acl}{ $stream->key } & 4 ) ) { # TODO:constant
        $c->render('stream/403');
        return;
    }


    $c->render();
}

sub info {
    my $c = shift;

    # vzdy aktualizovat
    $c->session->{user}{acl} = $c->schema->resultset('ACL')->user_acl(
        $c->session->{user}
    );

    # stream
    my $stream = $c->schema->resultset('Stream_view')->find({
        id => $c->stash->{id}
    });

    if ( ! $stream ) {
        $c->render('stream/404');
        return;
    }

    my $rights = $c->session->{user}{acl}{ $stream->key };

    if ( ! $rights ) {
        $c->render('stream/403');
        return;
    }

    $c->stash->{stream} = {
        $stream->get_columns(),
        is_live       => $stream->is_live,
        is_writeable  => $stream->is_writeable( $rights ),
        is_recordable => $stream->is_recordable( $c->session->{user}{username} ),
    };

    $c->render();
}

1;

__END__

